Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ATACADAO S.A.
CNPJ: 75.315.333/0121-15 Inscrição Estadual: 1090362886
ROD RST 287, 5500, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 139681 Série: 503 Data de Emissão: 30/09/2019 20:00:26
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0975 3153 3301 2115 6550 3000 1396 8110 4857 9171
Protocolo de Autorização: 143191341410553
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
14691938 | BATATA LAVADA | 1,932 | KG | 2,99 | 5,78
14692998 | CEBOLA ATACADAO | 1,76 | KG | 3,1 | 5,46
2488999 | LARANJA PERA Kg | 2,688 | KG | 1,49 | 4,01
1825917 | MACA NAC.GALA | 1,188 | KG | 4,79 | 5,69
55896911 | RF.BROCOLIS LAR CONG | 1 | UN | 8,49 | 8,49
1920905 | CENOURA | 1,872 | KG | 2,69 | 5,04
1923990 | CHUCHU | 1,728 | KG | 2,49 | 4,30
37581961 | PALETA FRIBOI PORC. | 1,378 | KG | 15,99 | 22,03
1832917 | MARACUJA AZEDO | 0,648 | KG | 8,49 | 5,50
59113962 | RF.QUEIJO PRATO FAT. | 1 | UN | 13,98 | 13,98
59114921 | QJO MUSS.FAT.FRIMES | 1 | UN | 13,98 | 13,98
64942975 | CARNE MOIDA BDJ. | 1 | UN | 10,99 | 10,99
11874800 | FEIJAO KICALDO | 1 | UN | 4,95 | 4,95
36879933 | UVA ITALIA | 1 | UN | 7,49 | 7,49
12474982 | ARROZ CAMIL AG.T1 | 2 | UN | 1,98 | 3,96
53104889 | RF.MIX C.GRANO CONG | 1 | UN | 7,49 | 7,49
62249957 | ATUM ROBINSON | 4 | UN | 4,29 | 17,16
14201952 | LEITE L.VIDA MOLICO | 4 | UN | 3,35 | 13,40
32150118 | PAO FORMA S.BOYS | 1 | UN | 4,9 | 4,90
63473915 | AZEITE OLIVA TERRAS | 1 | UN | 12,9 | 12,90
5810337 | ALFACE CRESPA HID. | 1 | UN | 2,5 | 2,50
14191983 | LEITE L. VIDA NINHO | 2 | UN | 3,35 | 6,70
28865914 | MASSA PIZZA ROMENA | 4 | UN | 2,99 | 11,96
28850933 | AGUA M.FLORESTA PET | 4 | UN | 4,29 | 17,16
1075102 | MELANCIA GD | 1 | UN | 10,99 | 10,99
Valor total R$ | 225,70
Valor descontos R$ | 1,11
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:39